==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/ArrayCore/src/ConvFKVertical.cpp <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-05-08
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "FKCrossSpectrum.h"
#include "FKPower.h"
#include "ConvFKVertical.h"

namespace ArrayCore {

  /*!
    \class ConvFKVertical ConvFKVertical.h
    \brief Vertical conventional FK power

    Vertical conventional FK power versus wavenumber (k) function.
  */

  void ConvFKVertical::resetCrossSpectrum()
  {
    _crossSpectrum->resetRayleigh();
  }

  void ConvFKVertical::addCrossSpectrum()
  {
    _crossSpectrum->addVertical();
  }

  void ConvFKVertical::meanCrossSpectrum(int nBlocks)
  {
    _crossSpectrum->meanRayleigh(nBlocks);
  }

  double ConvFKVertical::value(const Point& k, int index) const
  {
    if(isInsideLimits(k)) {
      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
      p.setConventionalValue(_crossSpectrum->rayleigh());
      return p.value();
    } else {
      return -1.0;
    }
  }

  double ConvFKVertical::value(const Point& k) const
  {
    if(isInsideLimits(k)) {
      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
      s->initValue(k);
      FKPower p(s);
      p.setConventionalValue(_crossSpectrum->rayleigh());
      return p.value();
    } else {
      return -1.0;
    }
  }

} // namespace ArrayCore

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/ArrayCore/src/ConvFKVertical.cpp <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-05-08
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "FKCrossSpectrum.h"
#include "FKPower.h"
#include "ConvFKVertical.h"

namespace ArrayCore {

  /*!
    \class ConvFKVertical ConvFKVertical.h
    \brief Vertical conventional FK power

    Vertical conventional FK power versus wavenumber (k) function.
  */

  void ConvFKVertical::resetCrossSpectrum()
  {
    _crossSpectrum->resetMatrix();
  }

  void ConvFKVertical::addCrossSpectrum()
  {
    _crossSpectrum->addVertical();
  }

  void ConvFKVertical::meanCrossSpectrum(int nBlocks)
  {
    _crossSpectrum->meanMatrix(nBlocks);
  }

  double ConvFKVertical::value(const Point& k, int index) const
  {
    if(isInsideLimits(k)) {
      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
      p.setConventionalValue(_crossSpectrum->matrix());
      return p.value();
    } else {
      return -1.0;
    }
  }

  double ConvFKVertical::value(const Point& k) const
  {
    if(isInsideLimits(k)) {
      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
      s->initValue(k);
      FKPower p(s);
      p.setConventionalValue(_crossSpectrum->matrix());
      return p.value();
    } else {
      return -1.0;
    }
  }

} // namespace ArrayCore
